==> haskell-hackage-security-0.5.2.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hackage-security
version: 0.5.2.2
id: hackage-security-0.5.2.2-DGhcS93k8AW50aWD4VcMbD
key: hackage-security-0.5.2.2-DGhcS93k8AW50aWD4VcMbD
license: BSD3
copyright: Copyright 2015-2016 Well-Typed LLP
maintainer: edsko@well-typed.com
homepage: https://github.com/well-typed/hackage-security
synopsis: Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<http://hackage.haskell.org/>).  It is based on The Update
    Framework (<http://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).
    .
    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.
    .
    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).
category: Distribution
author: Edsko de Vries
exposed: True
indefinite: False
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.IO
    Hackage.Security.Util.Lens Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical
hidden-modules: Hackage.Security.Key Hackage.Security.Trusted.TCB
                Hackage.Security.TUF Hackage.Security.TUF.Common
                Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
                Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
                Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
                Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
                Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
                Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
                Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
                Hackage.Security.Util.JSON Hackage.Security.Util.Stack
                Hackage.Security.Util.TypedEmbedded Prelude
abi: 8691339f34ee47b58a346f1ed4f7bfca
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hackage-security-0.5.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/hackage-security-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/hackage-security-0.5.2.2
hs-libraries: HShackage-security-0.5.2.2-DGhcS93k8AW50aWD4VcMbD
depends:
    base-4.10.0.0 base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    bytestring-0.10.8.2 Cabal-2.0.0.2 containers-0.5.10.2
    directory-1.3.0.2 ed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo
    filepath-1.4.1.2 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh pretty-1.1.3.3
    cryptohash-sha256-0.11.100.1-7zhEa02dR4aEFqZ0S7VT8y
    tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M time-1.8.0.2
    transformers-0.5.2.0 zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    template-haskell-2.12.0.0 ghc-prim-0.5.1.0
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=8eee912e61521dafabce3d6c55a8e0d0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             Cabal-2.0.0.2=967894c66ebadf39b2418a365180d683
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             ed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo=16e40b41929e410b9b5dc09d9137dbc1
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=e1133adbf062e57f52fe5f364651e21e
             pretty-1.1.3.3=e10ebff28b4fc258fa0291d45c86289c
             cryptohash-sha256-0.11.100.1-7zhEa02dR4aEFqZ0S7VT8y=f9b711c4531767b371173d2362631780
             tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M=83854589d621afa390620ba60c966f5e
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=b376f34fdf020268b43dfcb638579ae4
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             ghc-prim-0.5.1.0=fda2a11477a7bf13cbe78cc4c41e22f7
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
haddock-interfaces: /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock
haddock-html: /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-security-0.5.2.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hackage-security.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hackage-security
version: 0.5.2.2
id: hackage-security-0.5.2.2-K7Hii18vR2BJeeM2SQ3yHs
key: hackage-security-0.5.2.2-K7Hii18vR2BJeeM2SQ3yHs
license: BSD3
copyright: Copyright 2015-2016 Well-Typed LLP
maintainer: edsko@well-typed.com
homepage: https://github.com/well-typed/hackage-security
synopsis: Hackage security library
description:
    The hackage security library provides both server and
    client utilities for securing the Hackage package server
    (<http://hackage.haskell.org/>).  It is based on The Update
    Framework (<http://theupdateframework.com/>), a set of
    recommendations developed by security researchers at
    various universities in the US as well as developers on the
    Tor project (<https://www.torproject.org/>).
    .
    The current implementation supports only index signing,
    thereby enabling untrusted mirrors. It does not yet provide
    facilities for author package signing.
    .
    The library has two main entry points:
    "Hackage.Security.Client" is the main entry point for
    clients (the typical example being @cabal@), and
    "Hackage.Security.Server" is the main entry point for
    servers (the typical example being @hackage-server@).
category: Distribution
author: Edsko de Vries
exposed: True
indefinite: False
exposed-modules:
    Hackage.Security.Client Hackage.Security.Client.Formats
    Hackage.Security.Client.Repository
    Hackage.Security.Client.Repository.Cache
    Hackage.Security.Client.Repository.HttpLib
    Hackage.Security.Client.Repository.Local
    Hackage.Security.Client.Repository.Remote
    Hackage.Security.Client.Verify Hackage.Security.JSON
    Hackage.Security.Key.Env Hackage.Security.Server
    Hackage.Security.TUF.FileMap Hackage.Security.Trusted
    Hackage.Security.Util.Checked Hackage.Security.Util.IO
    Hackage.Security.Util.Lens Hackage.Security.Util.Path
    Hackage.Security.Util.Pretty Hackage.Security.Util.Some
    Text.JSON.Canonical
hidden-modules: Hackage.Security.Key Hackage.Security.Trusted.TCB
                Hackage.Security.TUF Hackage.Security.TUF.Common
                Hackage.Security.TUF.FileInfo Hackage.Security.TUF.Header
                Hackage.Security.TUF.Layout.Cache Hackage.Security.TUF.Layout.Index
                Hackage.Security.TUF.Layout.Repo Hackage.Security.TUF.Mirrors
                Hackage.Security.TUF.Paths Hackage.Security.TUF.Patterns
                Hackage.Security.TUF.Root Hackage.Security.TUF.Signed
                Hackage.Security.TUF.Snapshot Hackage.Security.TUF.Targets
                Hackage.Security.TUF.Timestamp Hackage.Security.Util.Base64
                Hackage.Security.Util.JSON Hackage.Security.Util.Stack
                Hackage.Security.Util.TypedEmbedded Prelude
abi: 0fe9ebce929a8b16dda2f16f32f4da82
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hackage-security-0.5.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/hackage-security-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/hackage-security-0.5.2.2
hs-libraries: HShackage-security-0.5.2.2-K7Hii18vR2BJeeM2SQ3yHs
depends:
    base-4.10.0.0 base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    bytestring-0.10.8.2 Cabal-2.0.0.2 containers-0.5.10.2
    directory-1.3.0.2 ed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo
    filepath-1.4.1.2 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh pretty-1.1.3.3
    cryptohash-sha256-0.11.101.0-I1K3fYbQvGGIBL2HcVgfRG
    tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M time-1.8.0.2
    transformers-0.5.2.0 zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    template-haskell-2.12.0.0 ghc-prim-0.5.1.0
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             base16-bytestring-0.1.1.6-1RelFaTH3mXDxpXrCeJSko=8eee912e61521dafabce3d6c55a8e0d0
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             Cabal-2.0.0.2=967894c66ebadf39b2418a365180d683
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             ed25519-0.0.5.0-9NT4KzgzBhXCnbKiU3eJSo=16e40b41929e410b9b5dc09d9137dbc1
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=e1133adbf062e57f52fe5f364651e21e
             pretty-1.1.3.3=e10ebff28b4fc258fa0291d45c86289c
             cryptohash-sha256-0.11.101.0-I1K3fYbQvGGIBL2HcVgfRG=d2e1c76dd47e1ec6800960b6a3f4756f
             tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M=83854589d621afa390620ba60c966f5e
             time-1.8.0.2=e9c7416c5b79f57513fe11898c3d9f95
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=b376f34fdf020268b43dfcb638579ae4
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             ghc-prim-0.5.1.0=fda2a11477a7bf13cbe78cc4c41e22f7
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=0d8dbc66a8173770b7f27b72bc5a4600
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=06cb668c0e9e66cc22d17c21c1fa2e38
haddock-interfaces: /usr/share/doc/haskell-hackage-security/html/hackage-security.haddock
haddock-html: /usr/share/doc/haskell-hackage-security/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
